==> ui-components-0.1.0.tgz: package/stories/02-Buttons/02-CircleButton.stories.tsx <==
import CircleButton, {
  CircleButtonProps,
} from "../../src/buttons/CircleButton";
import { Meta, Story } from "@storybook/react";

import React from "react";
import { faCoffee } from "@fortawesome/free-solid-svg-icons";
import mamoru from "../images/mamoru.png";

export default {
  title: "Buttons/Circle Button",
  component: CircleButton,
  parameters: {
    actions: {
      handles: ["click button"],
    },
  },
  decorators: [
    (Story) => (
      <div className="story">
        {Story()}
        <style jsx>{`
          .story {
            display: flex;
            justify-content: space-evenly;
            flex-wrap: wrap;
            height: 45px;
          }
        `}</style>
      </div>
    ),
  ],
} as Meta;

const ButtonTemplate: Story<CircleButtonProps> = (args) => {
  return <CircleButton {...args} />;
};

export const Regular = ButtonTemplate.bind({});
Regular.args = {
  icon: faCoffee,
  link: {
    onClick: () => {
      // This is already handled by the config parameters above
    },
  },
  accentColor: "red",
};

export const WithBorderColor = ButtonTemplate.bind({});
WithBorderColor.args = {
  ...Regular.args,
  defaultBorderColor: "magenta",
};

export const WithDropdown = ButtonTemplate.bind({});
WithDropdown.args = {
  ...Regular.args,
  withDropdown: true,
};

export const WithNotificationDot = ButtonTemplate.bind({});
WithNotificationDot.args = {
  ...Regular.args,
  withNotification: true,
};

export const WithNotificationDotAndBorder = ButtonTemplate.bind({});
WithNotificationDotAndBorder.args = {
  ...WithNotificationDot.args,
  defaultBorderColor: "cyan",
};

export const WithNotificationDotAndSelected = ButtonTemplate.bind({});
WithNotificationDotAndSelected.args = {
  ...WithNotificationDot.args,
  selected: true,
  accentColor: "red",
};

export const Selected = ButtonTemplate.bind({});
Selected.args = {
  ...Regular.args,
  selected: true,
  accentColor: "red",
};

export const Loading = ButtonTemplate.bind({});
Loading.args = {
  ...Selected.args,
  loading: true,
};

export const WithImage = ButtonTemplate.bind({});
WithImage.args = {
  ...Regular.args,
  icon: mamoru,
};

export const WithBlurredImage = ButtonTemplate.bind({});
WithBlurredImage.args = {
  ...Regular.args,
  icon: mamoru,
  blurred: true,
};

==> ui-components-0.3.2.tgz: package/stories/02-Buttons/02-CircleButton.stories.tsx <==
import CircleButton, { CircleButtonProps } from "buttons/CircleButton";
import { Meta, Story } from "@storybook/react";

import React from "react";
import { faCoffee } from "@fortawesome/free-solid-svg-icons";
import mamoru from "stories/images/mamoru.png";

export default {
  title: "Buttons/Circle Button",
  component: CircleButton,
  parameters: {
    actions: {
      handles: ["click button"],
    },
  },
  decorators: [
    (Story) => (
      <div className="story">
        {Story()}
        <style jsx>{`
          .story {
            display: flex;
            justify-content: space-evenly;
            flex-wrap: wrap;
            height: 45px;
          }
        `}</style>
      </div>
    ),
  ],
} as Meta;

const ButtonTemplate: Story<CircleButtonProps> = (args) => {
  return <CircleButton {...args} />;
};

export const Regular = ButtonTemplate.bind({});
Regular.args = {
  icon: { icon: faCoffee },
  link: {
    onClick: () => {
      // This is already handled by the config parameters above
    },
  },
  accentColor: "red",
};

export const WithBorderColor = ButtonTemplate.bind({});
WithBorderColor.args = {
  ...Regular.args,
  defaultBorderColor: "magenta",
};

export const WithDropdown = ButtonTemplate.bind({});
WithDropdown.args = {
  ...Regular.args,
  withDropdown: {},
};

export const WithNotificationDot = ButtonTemplate.bind({});
WithNotificationDot.args = {
  ...Regular.args,
  withNotification: {},
};

export const WithNotificationDotAndBorder = ButtonTemplate.bind({});
WithNotificationDotAndBorder.args = {
  ...WithNotificationDot.args,
  defaultBorderColor: "cyan",
};

export const WithNotificationDotAndSelected = ButtonTemplate.bind({});
WithNotificationDotAndSelected.args = {
  ...WithNotificationDot.args,
  selected: true,
  accentColor: "red",
};

export const Selected = ButtonTemplate.bind({});
Selected.args = {
  ...Regular.args,
  selected: true,
  accentColor: "red",
};

export const Loading = ButtonTemplate.bind({});
Loading.args = {
  ...Selected.args,
  loading: true,
};

export const WithImage = ButtonTemplate.bind({});
WithImage.args = {
  ...Regular.args,
  icon: { icon: mamoru },
};

export const WithBlurredImage = ButtonTemplate.bind({});
WithBlurredImage.args = {
  ...Regular.args,
  icon: { icon: mamoru },
  blurred: true,
};
